AttachmentSheet class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AttachmentSheet
Constructors
-
AttachmentSheet({required BuildContext context, dynamic onCameraTap(List<
File> )?, dynamic onGalleryTap(List<File> )?, dynamic onAudioTap(List<File> )?, dynamic onDocSelect(List<File> )?, void onContactSelect(Map<String, dynamic> )?, bool showCamera = true, bool showGallery = true, bool showAudio = true, bool showDoc = true, bool showContact = true, Color backgroundColor = Colors.white, Color iconColor = Colors.black, Color textColor = Colors.black, Color iconBackgroundColor = const Color(0xFFE0E0E0), Key? key}) -
const
Properties
- backgroundColor → Color
-
final
- context → BuildContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconBackgroundColor → Color
-
final
- iconColor → Color
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onAudioTap
→ dynamic Function(List<
File> )? -
final
-
onCameraTap
→ dynamic Function(List<
File> )? -
final
-
onContactSelect
→ void Function(Map<
String, dynamic> )? -
final
-
onDocSelect
→ dynamic Function(List<
File> )? -
final
-
onGalleryTap
→ dynamic Function(List<
File> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAudio → bool
-
final
- showCamera → bool
-
final
- showContact → bool
-
final
- showDoc → bool
-
final
- showGallery → bool
-
final
- textColor → Color
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAudioTapEvent(
) → void -
onCameraTapEvent(
) → void -
onContactSelectEvent(
) → void -
onDocSelectEvent(
) → void -
onGalleryTapEvent(
) → void -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited