AttachmentConfig class
Constructors
-
AttachmentConfig({dynamic onCameraFilesPicked(List<
File> )?, dynamic onGalleryFilesPicked(List<File> )?, dynamic onAudioFilesPicked(List<File> )?, dynamic onDocFilerPicked(List<File> )?, void onContactPicked(Map<String, dynamic> )?, Color backgroundColor = Colors.white, Color iconColor = Colors.black, Color textColor = Colors.black, Color iconBackgroundColor = const Color(0xFFE0E0E0), bool showCamera = true, bool showGallery = true, bool showAudio = true, bool showDoc = true, bool showContact = true}) -
const
Properties
- backgroundColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconBackgroundColor → Color
-
final
- iconColor → Color
-
final
-
onAudioFilesPicked
→ dynamic Function(List<
File> )? -
final
-
onCameraFilesPicked
→ dynamic Function(List<
File> )? -
final
-
onContactPicked
→ void Function(Map<
String, dynamic> )? -
final
-
onDocFilerPicked
→ dynamic Function(List<
File> )? -
final
-
onGalleryFilesPicked
→ dynamic Function(List<
File> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAudio → bool
-
final
- showCamera → bool
-
final
- showContact → bool
-
final
- showDoc → bool
-
final
- showGallery → bool
-
final
- textColor → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited